# vim: set sw=4 ts=4 et:
# Copyright (c) 2010-2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2005-2010 oc2pus
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           mixxx-unstable
Summary:        Open Source DJ tool
Version:        20171218.a1449f382
Release:        1.1
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/mixxxdj/mixxx
Source0:        %{name}-%{version}.tar.xz
Source99:       mixxx-unstable-rpmlintrc
Patch0:         mixxx.soundtouch.patch
Patch1:         mixxx.widgethider.patch
Patch2:         mixxx.scons.patch
ExclusiveArch:  %ix86 x86_64
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkg-config
BuildRequires:  scons
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  libebur128-devel
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  portmidi-devel

BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)

BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(gl)
BuildRequires:  freeglut-devel
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(libchromaprint)
BuildRequires:  pkgconfig(rubberband)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(id3tag)
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(hidapi-libusb)
%endif
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(shout)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(vamp-sdk)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  gperftools-devel

BuildRequires:  update-desktop-files
BuildRequires:  fdupes
BuildRequires:  alsa-devel

Obsoletes:      %{name}-skin-hercules
Obsoletes:      %{name}-skin-outlineClose
Obsoletes:      %{name}-skin-outline
Obsoletes:      %{name}-skin-outlineMini
Obsoletes:      %{name}-skin-outlineNetbook
Obsoletes:      %{name}-skin-nCut
Obsoletes:      %{name}-skin-Collusion
Obsoletes:      %{name}-skin-traditional
Recommends:     libmp3lame0
Requires:       vamp-qm-plugins
#BuildRequires:  libqt4-sql-sqlite
#Requires:       libqt4-sql-sqlite
Provides:       mixxx = %{version}-%{release}
Conflicts:      mixxx

%description
Mixxx is designed for DJ'ing for both professional and
semi-professional users.
Mixxx was started in early 2001 as one of the first digital
DJ systems.

Today Mixxx includes many features common to digital DJ solutions,
but also some very unique features: It is free, and runs on all
major desktop operating systems.

Furthermore Mixxx has a number of key features to help the DJ in
the live mix: Beat estimation, parallel visual displays, and
support for many DJ input controllers.

Mixxx is software for DJ'ing. You can use wave based audio files,
Ogg Vorbis and MP3 files as audio input. Mixxx can be controlled
through the GUI and with external controllers including MIDI
devices, joysticks and more.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
pushd lib
rm -rf *ebur128*
if pkg-config --exists soundtouch >= 1.8.0
then
rm -rf *soundtouch*
fi
rm -rf *vamp*
if pkg-config --exists hidapi-libusb
then
rm -rf *hidapi*
fi
popd

# regenerate protobuf code with the current version
# of protobuf (not doing so fails the build):
pushd src/proto
protoc beats.proto --cpp_out=.
popd #src/proto

env \
LIBDIR='%{_libexecdir}' \
scons %{?_smp_mflags} \
    prefix="%{_prefix}" \
    vinylcontrol=1 \
    qt5=1 \
    ffmpeg=0 \
    flac=1 \
    mad=1 \
    modplug=1 \
    opus=1 \
    sndfile=1 \
    faad=0 \
    shoutcast=1 \
    ipod=0 \
    hid=1 \
    bulk=1 \
    vamp=1 \
    wv=1 \
    asmlib=1 \
    qdebug=1 \
    verbose=0 \
    buildtime=0 \
    localecompare=0 \
    qt_sqlite_plugin=1 \
    perftools=1

%install
scons \
    prefix="%{_prefix}" \
    install_root="%{buildroot}%{_prefix}" \
    qt5=1 \
    install

rm -rfv '%{buildroot}%{_datadir}/doc/mixxx'

%suse_update_desktop_file -r mixxx AudioVideo Player Jukebox

L="$PWD/%{name}.lang"
echo -n > "$L"
pushd "%{buildroot}%{_datadir}/mixxx/translations"
/bin/ls -1 mixxx_*.qm | while read f; do
    [ -e "$f" ] || continue
    l="${f#mixxx_}"
    l="${l%.qm}"
    echo "%lang($l) %{_datadir}/mixxx/translations/$f" >> "$L"
done
popd

# hardlinks are required to speedup build
%fdupes "%{buildroot}%{_datadir}/mixxx/skins"

%files -f %{name}.lang
%defattr(-,root,root)
%doc COPYING LICENSE Mixxx-Manual.pdf README*
%{_bindir}/mixxx
%{_libexecdir}/mixxx
%dir %{_datadir}/mixxx
%dir %{_datadir}/mixxx/translations
%{_datadir}/mixxx/controllers
%{_datadir}/mixxx/fonts
%{_datadir}/mixxx/keyboard
%{_datadir}/mixxx/skins
%{_datadir}/applications/mixxx.desktop
%{_datadir}/pixmaps/mixxx-icon.png
%dir %{_datadir}/appdata
%{_datadir}/appdata/mixxx.appdata.xml

%changelog
* Tue Dec 19 2017 olaf@aepfle.de
- Update to 20171218.a1449f382
* Wed Aug  2 2017 olaf@aepfle.de
- Update to 20170731.5b5ba9942
* Sun Mar 12 2017 olaf@aepfle.de
- Disable mp4 and faad because libmp4v2 was dropped
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Wed Apr  9 2014 johannesobermayr@gmx.de
- update to latest git master
- remove obsolete patches
  * mixxx-disable_qt_rpath.patch
  * mixxx-fix_modifying_const_qstring.patch
  * mixxx.desktop
  * repackage.sh
* Wed Aug 14 2013 pascal.bleser@opensuse.org
- update to 20130814120754
* Sun Aug 11 2013 pascal.bleser@opensuse.org
- update to 20130809184906
- add support for modplug
* Sat Jun 15 2013 pascal.bleser@opensuse.org
- update to 3430
  * fixes bug(s): https://launchpad.net/bugs/1025007
    Fix issue in EngineBufferScaleLinear that can cause loops to go out of
    sync. Fixes Bug #1025007.
  * fix vinyl input toggling not working correctly
  * don't crash if user has a keyboard key configured for a control that doesn't exist
* Wed Jun  5 2013 pascal.bleser@opensuse.org
- update to 3412:
  * fixes bug(s): https://launchpad.net/bugs/1185787
    add 3/4 BPM scaling option, fixes Bug #1185787
  * fixes bug(s): https://launchpad.net/bugs/1184324
    Fix segfault in dlgtagfetcher see Bug #1184324
* Sun May 26 2013 pascal.bleser@opensuse.org
- update to 3404:
  * fixes bug(s): https://launchpad.net/bugs/1184324
    Fix segfault in dlgtagfetcher see Bug #1184324
  * fixes bug(s): https://launchpad.net/bugs/1088031
    Add new BPM context menu with for easy BPM manipulation, fix Bug #1088031
* Sun May 26 2013 pascal.bleser@opensuse.org
- update to 3403:
  * 3403 Max Linke	2013-05-25
    fixes bug(s): https://launchpad.net/bugs/1088031
    Add new BPM context menu with for easy BPM manipulation, fix Bug #1088031
* Thu May 23 2013 pascal.bleser@opensuse.org
- update to 3402:
  * fixes bug(s): https://launchpad.net/bugs/976580
    Add horizontal scroll-bar in treeview pane
* Wed May 22 2013 pascal.bleser@opensuse.org
- update to 3397:
  * fixes bug(s): https://launchpad.net/bugs/804700
    merge with chromaprint branch Fix Bug #804700
  * Only apply pre-amp gain if it is greater than 1.
* Tue May 21 2013 pascal.bleser@opensuse.org
- update to 3385
* Mon May 20 2013 pascal.bleser@opensuse.org
- update to 3380:
  * Fix hang-on-exit deadlock in VinylControlManager. This is triggered by the
    recent collapsing of ControlObject and ControlObjectThread.
* Tue May  7 2013 pascal.bleser@opensuse.org
- update to 3365:
  * support mono input (just in case)
  * bring back EnginePassthrough since we could use it for an auxiliary input
  * version bump to 1.12.0-alpha-pre
  * cherry-pick schema version 18 from features_key so beta testers can use it
    without getting out of sync with whatever happens to the schema in trunk
* Sun May  5 2013 pascal.bleser@opensuse.org
- update to 3358:
  * Get rid of VampAnalyser default max of 10-minutes! I can't believe this
    made it past the beta. Anyone using non-fixed-tempo assumption has
    beatgrids that are only 10-minutes long now.
  * Also commit beatsSubVersion to the database when adding a new track. This
    is low impact because Beats only have sub-versions if they are already
    scanned by the library scanner and to be scanned by the library scanner
    typically they are in the database already.
* Sat May  4 2013 pascal.bleser@opensuse.org
- update to 3357:
  * fixes bug(s): https://launchpad.net/bugs/355945
  * commit Vinyl Passthrough patch
* Fri May  3 2013 pascal.bleser@opensuse.org
- update to 3356:
  * merge with bpmdelegate branch
* Thu May  2 2013 pascal.bleser@opensuse.org
- update to 3355:
  * Rollback of r3855. This is half-baked and should wait.
  * Turn off keylock temporarily while controller scratching is enabled. This
    unifies the behavior of vinyl scratching, mouse scratching, and controller
    scratching in this respect. Fixes Bug #1174578
* Sun Apr 28 2013 pascal.bleser@opensuse.org
- update to 3354:
  * Translation String now are set to UTF-8, fixes bug #997104
* Sun Apr 28 2013 pascal.bleser@opensuse.org
- update to 3353:
  * Fix performance issue with gigantic libaries and empty crates/playlists
  * Fix https://launchpad.net/bugs/1171235 (Importing playlists/crates is
    really slow)
  * When table selection changes in DlgPrepare, enable the analysis button if
    an analysis is currently running. Fixes Bug #1171083
* Wed Apr 24 2013 pascal.bleser@opensuse.org
- update to 3351:
  * Change how isnan() is defined across Mixxx. Hopefully fixes Bug #1128419.
  * display playlst and library timestamps in the user's local timezone. Fixes
    Bug #1036492
  * Faster playlist/crate importing (fixes #1171235)
  * Use naming scheme <vendor name><device name> in presets drop down menu for
    KMI QueNeo preset like we do for all other presets
  * Fix parsing error in MixVibes U-Mix Control Pro 2 preset
  * remove the fixed number of Sampler Decks in the feature list since we ship
    skins with up to 16 and the user can add even more
  * add Mixvibes to the list of supported timecode media
  * Add another heuristic for linking MIDI input and output devices that
    matches numerals after the device name and ignores extra non-numeric
    symbols dangling beyond the numeral. This restriction should hopefully
    prevent us from getting confused by odd device names. Add corresponding
    tests to verify the originally reported issue is fixed. Fixes Bug #1165501
  * add missing changes from r3815 to man page
  * made [AutoDD],toggle_atodj to [AutoDJ],enabled, Bug #1166095
  * Update Linux man page for v1.11 . Fixes lp:1159150
  * Removes <BeatHighlightColor> from the waveforms, which blinks for a brief
    about of time to indicate when the beat is near the playposition. Fixes
    lp:1112396
  * Enable option to add track's key TrackProperty to the skin. This displays
    the musical key but does not change if the speed/pitch change during
    playback. Fixes lp:1159141
* Tue Apr  9 2013 pascal.bleser@opensuse.org
- update to 3350:
  * Log filename when ParseHeader is called in developer mode.
  * Add pattern-based device linking. Fixes Bug #1165501
  * Add Borfo's Korg nanoKONTROL 2 preset.
  * Add tomtom's MixVibes U-Mix Control Pro 2 preset.
  * Add peper's update to the MixVibes U-Mix Control 2 preset.
  * Add Borfo's update to the Akai LPD8 preset.
  * Add Borfo's updates to the DJ-Tech Mixer One preset.
  * Add Borfo's preset for the DJ-Tech Kontrol One.
  * Version bump to 1.11.0.
  * Remove quit on qCritical/qFatal and instead call a helper that
    qCritical/qFatal's and also issues a model messagebox which quits after the
    user presses ok. This prevents re-entrancy in MessageHandler.
  * merged changes from lp:mixxx r3340, fixing logfile mutex
  * added a dummy spinny when system has no openGL support. Possible fix for
    Bug #1160353
  * Fix duplicate QMutexLocker.
  * Fix minor thread safety issue in ErrorDialogHandler. (Guard accesses to
    QSignalMapper by holding mutex)
  * Resolve deadlock in MessageHandler. Fixes Bug #1160353
  * added spinback effect to control Air
  * Add CFBundleVersion to Info.plist.
* Thu Apr  4 2013 pascal.bleser@opensuse.org
- update to 3349:
  * Add ModPlug plugin.
    This adds a SoundSource for MOD/IT/XM/STM/S3M/OKT tracker formats. Other formats are supported
    by libmodplug, but file name extensions are not available in general. For now I only added formats I can test.
    If you are interested in other formats, just rename the files to a supported extension. Detection should work.
    Files are decoded and saved in RAM. Currently up to 250MB of RAM (~25min) are allowed per track. Most
    tracks are much shorter. This is mainly a precaution in case of endless loops.
  * fixes bug(s): https://launchpad.net/bugs/1162443
    added Albans patch for short sample bpm calculations, Bug #1162443
* Wed Apr  3 2013 pascal.bleser@opensuse.org
- update to 3346:
  * fixes bug(s): https://launchpad.net/bugs/1162351
    Added patch from Alban, fixing pitch step config, Bug #1162351
* Mon Apr  1 2013 pascal.bleser@opensuse.org
- update to 3344:
  * fixed Logfile mutex
  * cosmetic and code style fixes
* Sat Mar 30 2013 pascal.bleser@opensuse.org
- update to 3336:
  * color scheme for waveform marks, Bug #1107249
  * Optionally apply legacy library styling if LegacyTableViewStyle> is present
    in the skin. Fixes Bug #1159451
* Wed Mar 27 2013 pascal.bleser@opensuse.org
- update to 3335:
  * take rate range into account, Bug #1156319 and Bug #1156326
  * respect trackload settings in woverview, Fix Bug #1156309
* Fri Mar 22 2013 pascal.bleser@opensuse.org
- update to 3334:
  fixes bug(s): https://launchpad.net/bugs/884705
  show known latency, set audio buffer instead of latency
* Mon Mar 18 2013 pascal.bleser@opensuse.org
- update to 3333
* Tue Mar  5 2013 pascal.bleser@opensuse.org
- update to 3332
* Mon Feb 25 2013 seife+obs@b1-systems.com
- use gperftools on 12.2 or newer instead of old google-perftools
* Wed Jan  2 2013 pascal.bleser@opensuse.org
- update to 3319:
  * fixing some segfaults during skin designing
  * Update keybindings and wording in Menubar|View
  * added [Auto DJ] Requque config
* Wed Dec 26 2012 pascal.bleser@opensuse.org
- update to 3317:
  * fixed building with Qt 4.6
  * Remove double-unlock of thread/midi queues
  * Fix segfault on exit due to double-free when keyboard shortcuts are disabled
  * Fix tooltip mixxx.cfg format to be backwards compatible with 1.10.x
  * Add seperator in Options menu to un-group the keyboard shortcuts toggle
    from broadcasting and recording options
  * tracks can be dropped and loaded into the preview deck also when it's playing
* Sat Dec 22 2012 pascal.bleser@opensuse.org
- update to 3316:
  * fixed woverview current position at end of track, Bug #1087437
  * fixed woverview scaling, Bug #1084551
  * finished port of soundtouch analyser to a vamp plugin.
  * dlgprefbeats can now also handle several plugIns and will try to select QM
    on the first run.
  * Merging from lp:~mixxxdevelopers/mixxx/1.11-skins to get the latset skin
    updated and fixes. Fixes Bug #1090905
  * Update default play/pause icons for legacy skins used in the "Preview"
  * library column
  * Add missing graphics to Deere1920x1200-WUXGA which could lead to segfault
  * Use [PreviewDeck] instead of [Previewdeck] in Deere skins, following
    lp:1083662
  * Adds preview deck and more to the Deere Skin family
* Mon Dec 17 2012 pascal.bleser@opensuse.org
- update to 3315:
  * version bump to 1.11.0-pre
  * fix preview deck overview
  * implement searching by term on string-typed fields of dirty tracks
    ("comment:foobar")
  * HSV waveform widget/renderers
  * prioritize tracks with stored analysis in analysis queue
  * added transparency support for color scheme skins, fixes ghost image
    transparency in outline skin
  * fixed waveform marks
* Thu Dec 13 2012 pascal.bleser@opensuse.org
- update to 3314: bugfixes
* Tue Dec 11 2012 pascal.bleser@opensuse.org
- update to 3313:
  * document --developer flag
  * turn vsync back on: this completely gets rid of tearing on both my Mac and
    Linux laptops
  * make beat marks more opaque
  * visualise track loading, Bug #1080734
* Sun Dec  9 2012 pascal.bleser@opensuse.org
- update to 3312:
  * fixed analyse view sorting, Bug #1024769
  * fix SoundTouch warnings in AnalyserBpm
  * fix jitter when smoothfading replaygain
* Wed Dec  5 2012 pascal.bleser@opensuse.org
- update to 3311: merged from lp:mixxx/1.11
* Sat Dec  1 2012 pascal.bleser@opensuse.org
- update to 3310: merged from lp:mixxx/1.11
* Fri Nov 30 2012 pascal.bleser@opensuse.org
- update to 3308: Merging from lp:mixxx/1.11
* Fri Nov 23 2012 pascal.bleser@opensuse.org
- update to 3307: merging from lp:mixxx/1.11
* Wed Nov 21 2012 pascal.bleser@opensuse.org
- update to 3306:
  * Merging from 1.11 to get Interface prefs pane updates
* Sat Nov 17 2012 pascal.bleser@opensuse.org
- update to 3305: merged from lp:mixxx/1.11
* Wed Nov  7 2012 pascal.bleser@opensuse.org
- update to 3304: merged with lp:mixxx/1.11
* Thu Nov  1 2012 pascal.bleser@opensuse.org
- update to 3303: merging from lp:mixxx/1.11
* Sat Oct 27 2012 pascal.bleser@opensuse.org
- update to 3302: merged with lp:mixxx/1.11
* Fri Oct 12 2012 pascal.bleser@opensuse.org
- update to 3301: Merging from lp:mixxx/1.11
* Mon Sep 10 2012 pascal.bleser@opensuse.org
- update to 3297: merged with lp:mixxx/1.11
* Tue Sep  4 2012 pascal.bleser@opensuse.org
- update to 3294: merge from lp:mixxx/1.11
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 3292
* Fri Aug  3 2012 pascal.bleser@opensuse.org
- update to 3291: merged with lp:mixxx/1.11
* Sat Jul 28 2012 pascal.bleser@opensuse.org
- update to 3290: merged with lp:mixxx/1.11
* Tue Jul 17 2012 pascal.bleser@opensuse.org
- update to 3289: merged with lp:mixxx/1.11
* Sun Jul  8 2012 pascal.bleser@opensuse.org
- update to 3286: merged with lp:mixxx/1.11
* Mon Jun 25 2012 pascal.bleser@opensuse.org
- update to 3284:
  * add Numark N4 preset
  * version bump to 1.11.0 beta1
  * improve schema upgrade error messages. Fixes Bug lp#963408
  * clean up cues, analyses, crates and playlists on purge of tracks from the
    library. Fixes Bug lp#949828
  * re-enable bitrate column and allow bitrate: search queries. Fixes Bug
    lp#1008872
  * add Numark OMNI control preset
  * fix external drag and drop. Fixes Bug lp#1014842
  * close the preference dialog when quitting Mixxx. Fixes Bug lp#1007958
  * add a 'Hidden Tracks' view to Mixxx and change default terminology from
    'remove' to 'hide'. Fixes Bug lp#949828
  * set default recording folder to QDesktopServices::MusicLocation
  * on Linux, use a 5ms polling interval instead of 1ms. Workaround for Bug
    lp#990992 until we have a better fix.
  * Bug lp#1002330 fix some more star-rating issues.
  * give a hint to restart Mixxx when disable library feature
  * added complete 4-deck Reloop Terminal Mix4 preset
* Sun Jun 17 2012 pascal.bleser@opensuse.org
- add libqt4-sql-sqlite to requires
* Fri Jun  8 2012 pascal.bleser@opensuse.org
- update to 3250:
  * add patch to fix ghost drag and drop. Fixes Bug lp#1008737
  * dont shuffle tracks already loaded to a deck, disable buttons when auto Dj
    is disabled, fix bug lp#998920
  * searchbox refresh fixed and auto DJ search disabled, fixed bug lp#998836
    and bug lp#998836
  * shuffle works now, fix bug lp#1008899
  * history displays removed files, fix Bug lp#1008374
  * add Hercules DJ Control AIR preset
* Fri Jun  1 2012 pascal.bleser@opensuse.org
- update to 3243:
  * Add patch to revise waveform rendering (bump waveform storage version to
    3). This changes to max across waveform strides instead of taking the
    average, resulting in more detailed waveforms. Fixes Bug lp#976650
  * Add patch to allow editing star ratings without selecting the row. Fixes
    Bug lp#1002330
  * Fix right-click pushbuttons
  * Add normalized overview support (user enabled via preference).
    Non-normalized overview if scaled with overall visual gain.
  * Support beatloop_X_toggle and beatloop_X_enabled controls instead of the
    deprecated beatloop_x in Deere/LateNight/Shade/Outline skin.xml. This fixes
    beatloop GUI buttons to start the loop again on button up, see lp:1000829 &
    lp:902641
  * Keep a window of recent tracks and don't increment playcount if the current
  * playing track is in the recent track window. Fixes Bug lp#1000431
  * Fix BPM lock checkbox inconsistent behavior. Fixes Bug lp#1002051
  * add Hercules DJ Control AIR preset
  * add Behringer BCD2000 mapping
  * add Numark DJ2Go mapping v0.1
  * add edits to Numark MIXTRACK mapping (version 1.0b)
  * add Pandemoniums Novation Dicer 1.1 mapping
  * add Hercules DJ Console 4-Mx mapping
  * add updated Numark Mixtrack Pro mapping
  * add Denon MC3000 mapping v0.995
  * change waveform compensation gain to 2 from 2.4
* Mon May 21 2012 pascal.bleser@opensuse.org
- update to 3178:
  * fix BPM lock checkbox inconsistent behavior
  * check BPM-lock for selection to decide whether to allow the clear-beats
    option to be active
  * Do not save waveforms immediately after generating them since the track
    might not be saved yet. Save them when the track is saved in TrackDAO.
  * Merging from lp:~hile/mixxx/hidscripts
  * fixed recording folder, Bug lp#925663
  * Update blacklisting logic and add comments.
  * Merging from lp:~hile/mixxx/hidblacklist.
  * Merging from lp:~vrince/mixxx/waveform-2.0_pure-gl
  * Add to Auto-DJ Top with empty Auto-DJ, fix bug lp#982652
  * Add to Auto-DJ Top with empty Auto-DJ, fix bug lp#982652
  * fixed shortcuts for eject and LoadSelectedTrack, a partial fix for bug
    lp#999560
  * fixed missing shortcuts in tooltips, bug lp#696058
  * fix *.kbd.cfg location
  * additional keyboard layouts added
  * Load keyboard mappings based on actual keyboard layout, fix bug lp#686377
  * Delete AnalyserGainVamp and ReplayGain from libmixxxminimal.
  * Disable AnalyserGainVamp and use the built-in RG analyser for all analysis.
  * removed absolute path when loading lame, fix bug lp#920191
* Mon May 14 2012 pascal.bleser@opensuse.org
- update to 3146:
  * eject played track on end of Auto-DJ playlist, fix bug lp#995945
  * merging from lp:mixxx/1.10
  * fixed outline skin kill buttons
  * prevent HIDAPI from bailing out on non-critical libusb errors on Linux
* Sat May 12 2012 pascal.bleser@opensuse.org
- update to 3141:
  * Prevent HIDAPI from bailing out on non-critical libusb errors on Linux
  * Allow customization of Browse section Quick Links. Fixes Bug lp#912394
  * Fix deadlock in BrowseThread. Fixes Bug lp#955179
  * Make track analysis interruptable so loaded tracks always get preference
  * Use SoundSource samplerate instead of TrackInfoObject samplerate in
    AnalyserWaveform. Fixes crash when TagLib fails to read the samplerate.
    Fixes Bug lp#997818
  * Allow enabling/disabling of iTunes/Traktor/Rhythmbox. Fixes Bug lp#909395
  * Allow importing external-library playlists as a Mixxx playlist and also to
    add them to AutoDJ. Fixes Bug lp#798541
  * Add a locale preference option, allowing the user to choose a custom
    locale. Fixes Bug lp#952709
  * Fix bug lp#900255 losing keyboard release events
  * Show help text when clicking the main browse section
* Thu May 10 2012 pascal.bleser@opensuse.org
- update to 3128:
  * show help text when clicking the main browse section
  * suggest a filename based on the playlist name. lp#995267
  * convert all transactions to use ScopedTransaction so should never be a
    danger of leaving a transaction hanging
  * prioritize tracks that are loaded when choosing the next track to analyze
    in the AnalyserQueue
  * add a selectable Tracks File Path display in the now less high track editor
    dialog, general dialog clean up, fix lp#773423 & lp#996246
  * changes the Shortcut for "New crate" from CTRL+C to CTRL+STRG+N
  * merging from lp:~mixxxdevelopers/mixxx/1.11-skins
  * add right-click 'Open in file browser' context menu option lp#941379
  * write beat detection defaults to config file on startup so songs will
    analyze before preferences is opened
  * add waveform analyser to prepare-analyser-queue so that waveforms will be
    generated as part of a bulk-analysis as well
  * don't run the analyser-queue on tracks for which no analyser wants to do
    any work: big CPU savings if your library is already fully analyzed
* Sat May  5 2012 pascal.bleser@opensuse.org
- update to 3094:
  * merging from lp:mixxx/1.10
  * merging from lp:mixxx
  * Use Qt 4.8 APIs to load the appropriate Ui-language translation. Fixes
  * translations for e.g. German locale computers with English language
    preferences. Fixes Bug lp#958091
  * Add patch to allow toggling of keyboard shortcuts. Fixes Bug lp#685815
  * Added 6%% pitch range option, lp#990559
  * Rename 'Set Logs' to 'History'. Delete res/html and move text to be
    hard-coded in C++ so that we can get translations for them. Fixes Bug
    lp#954238 and lp#953243
  * Add local-presets-path (e.g. ~/.mixxx/presets/) to search path for script
    files
* Tue May  1 2012 pascal.bleser@opensuse.org
- update to 3086:
  * version bump to alpha2.
  * Merging latest skin updates from lp:~mixxxdevelopers/mixxx/1.11-skins.
  * Re-allow loading controller presets from ~/.mixxx/presets
  * Convert EQ kill buttons to use POWERWINDOW mode. Fixes Bug lp#918470
* Tue May  1 2012 pascal.bleser@opensuse.org
- update to 3081:
  * add patch for power-window style pushbutton support. If pressed and
    released quickly (within 300ms) acts like a toggle button. If held for
    longer, acts like a push-button. Make microphone-talkover a
    powerwindow-button. Fixes Bug lp#876139
* Tue May  1 2012 pascal.bleser@opensuse.org
- update to 3079:
  * fixes bug(s): https://launchpad.net/bugs/879084 : Unify wording, changes
    "Player"->"Deck" and "Song"->"Track" based on our current POT-file.
    Partially fix lp:879084
  * 3078: link libdl, not libld
* Mon Apr 30 2012 pascal.bleser@opensuse.org
- update to 3077:
  * add patch to allow changing of the recording directory via preferences.
    Fixes Bug LP#925663
  * add UNIX_LIB_PATH to CPPDEFINES so we can know what the path to user prefix
    lib directory
  * move vamp install library to <prefix>/lib/mixxx/plugins/vamp instead of
    <prefix>/lib/mixxx/
  * add checks for plugins in <prefix>/lib/mixxx/plugins/(vamp|soundsource) for
    vamp and soundsource plugins
  * fix bug with new right-click reset behavior for widgets
  * merging from lp:~mixxxcontributors/mixxx/waveforme-2.0. Many updates to
    waveform rendering.
  * fixes bug(s): https://launchpad.net/bugs/908175 : remove empty Ui::
    constructor call (it's implicit!) from every dialog. This was causing a
    strange bug with lupdate/lrelease that was screwing up some of our
    translations. lp#908175
  * Parse info section, schemaVersion and mixxxVersion when loading a preset.
    Write info section, schemaVersion and mixxxVersion when loading a preset.
    Show 'name by author' as loaded preset. Fix a bunch of presets that were
    missing names or had .midi.xml in their name.
  * Merging from lp:~mixxxdevelopers/mixxx/features_point_and_click. Adds
    point-and-click MIDI mapping and an improved learning workflow.
  * merging from lp:mixxx
  * merging features_controllerAbstraction. Migration of mappings from
    .mixxx/midi/ to controllers/ only works on a version upgrade (end-users)
  * merging from lp:mixxx/1.10
  * fixes bug(s): https://launchpad.net/bugs/987395
    + fix typo in Interface dialog, fixes lp:987395
    + simplify Grid layout in Interface dialog
* Mon Apr 23 2012 pascal.bleser@opensuse.org
- update to 3038:
  * update translations
* Sun Apr 22 2012 pascal.bleser@opensuse.org
- update to 3035
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- update to 3025:
  * fix bug when loading BeatGrid-2.0 protos where beat-length was not
    calculated
* Mon Apr 16 2012 pascal.bleser@opensuse.org
- update to 3023:
  * fix protobuf handling in build; build against libprotobuf instead
    of libprotobuf-lite
  * enable VAMP plugin for BPM analysis
* Sun Apr 15 2012 pascal.bleser@opensuse.org
- update to 3014:
  * merge features_vamp branch into trunk: this brings greatly improved BPM and
    beat detection to Mixxx
- changed Recommends to Requires for vamp-qm-plugins
* Sat Apr 14 2012 pascal.bleser@opensuse.org
- update to 3013:
  * 3013: Playlist tree refesh, fixed bug #980187
  * 3012: apply sorting for selection fixx bug lp#975564
* Fri Apr 13 2012 pascal.bleser@opensuse.org
- update to 3011:
  * 3007: merge lp:~mixxxcontributors/mixxx/waveforme-2.0 into lp:mixxx
    bringing a totally rewritten waveform system (with colored, filtered
    waveforms) to Mixxx and deleting ALL the old waveform code
  * 3000: add numeric filters and numeric range filter advanced search
    operators
  * 2995: playlist export sort order corrected
- dropped my patch to add key mapping functions, has been merged upstream
* Sun Mar 18 2012 pascal.bleser@opensuse.org
- disable vamp support again, not precise enough in its current state
* Fri Mar 16 2012 pascal.bleser@opensuse.org
- add support for vamp plugins for BPM counting, from the features_vamp branch;
  adds vamp-qm-plugins to Recommends (only required to use the new QM based
  BPM counting; without it, you can still use the regular built-in BPM
  counting from Mixxx)
* Tue Mar  6 2012 pascal.bleser@opensuse.org
- build with maximum optimization, enables SSE/SSE2/MMX, which also fixes the
  build on 32bit
- fix libmp3lame.so.0 detection on x86_64 (needed for shoutcasting in MP3)
* Sat Mar  3 2012 pascal.bleser@opensuse.org
- update to trunk rev 2988
- add patch for additional key mapping functions: _toggle, _minus_toggle,
  _zero, _one, _minus_one
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- don't use our optflags but, instead, use the optimization flags from
  upstream; that also fixes building on 12.1 where GCC crashed on assembler
  stuff; dropped mixxx-optflags.patch
* Tue Dec 27 2011 pascal.bleser@opensuse.org
- update to 1.10.0
* Fri Mar  4 2011 reddwarf@opensuse.org
- Add patch to fix mp4v2 availability check
* Wed Jan  6 2010 toni@links2linux.de
- update to 1.7.2
- reenabled m4a support
- This bugfix release addresses a number of issues that were discovered
  in 1.7.1, and is a recommended upgrade for all users
  Some of the changes include:
  Improved saving of ordered playlists
  Fixed MIDI support on OS X
  Optimize latency settings. This should improve compatibility with certain
  soundcards/APIs.
  Improved stability and error handling when loading certain songs.
* Sun Oct 25 2009 toni@links2linux.de
- update to 1.7.1
- This release incorporates many major improvements, hugely improved MIDI
  controller support, better vinyl control support, savable cue points, and
  many performance improvements and bugfixes.
- disabled cmetrics and m4a (won't compile)
* Sat Oct  4 2008 toni@links2linux.de
- update to 1.6.1
- removed skin sub-package (skin-Natt)
* Fri Aug  8 2008 toni@links2linux.de
- update to 1.6.0
- enabled shoutcast and iPod support
* Sat Jul 19 2008 toni@links2linux.de
- update to 1.6.0beta4
- added new skin sub-package (skin-Natt)
* Sat May 31 2008 toni@links2linux.de
- update to 1.6.0beta3
* Sun Feb 10 2008 toni@links2linux.de
- update to 1.6.0beta2
* Sat Sep  8 2007 toni@links2linux.de
- openSUSE-10.3 build, corrected BuildRequires
* Wed Mar  7 2007 toni@links2linux.de
- added -lusb in build.definition (is NOT using pkg-config!)
* Sun Mar  4 2007 toni@links2linux.de
- update to 1.5.0.1
- replaced portaudio18 with portaudio
- added libdjconsole support
* Tue Jan  2 2007 toni@links2linux.de
- build SuSE-10.2, corrected BuildRequires
* Thu Nov 30 2006 toni@links2linux.de
- update to 1.5.0beta2
- added debug_package
* Fri Sep 29 2006 toni@links2linux.de
- update to 1.5.0 (cvs 29.09.2006)
- adjusted BuildRequires
* Sun Sep 17 2006 toni@links2linux.de
- build for packman
* Thu Sep  7 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060907
- update to 1.5.0 (cvs 07.09.2006)
* Thu Aug 24 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060824
- update to 1.5.0 (cvs 24.08.2006)
* Mon Aug 14 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060814
- update to 1.5.0 (cvs 14.08.2006)
* Thu Aug 10 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060810
- update to 1.5.0 (cvs 10.08.2006)
* Wed May 31 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060531
- update to 1.5.0 (cvs 31.05.2006)
* Sat May 20 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060520
- update to 1.5.0 (cvs 20.05.2006)
* Sun Apr 23 2006 oc2pus@arcor.de 1.5.0beta1-0.oc2pus.1
- update to 1.5.0beta1
- patched to use package soundtouch=1.3
- patched to use package portaudio18
- repacked without soundtouch and portaudio18* sources
- sub-packages for skins (hercules, outlineClose, outline, traditional)
  - changed menu-entry
* Wed Mar 29 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060329
- update to 1.5.0 (cvs 29.03.2006)
* Fri Feb 24 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060224
- update to 1.5.0 (cvs 24.02.2006)
- added --enable-python
* Sat Jan 28 2006 oc2pus@arcor.de 1.5.0-0.oc2pus.cvs20060128
- update to 1.5.0 (cvs 28.01.2006)
- patched to use package soundtouch=1.3
- patched to use package portaudio18
- sub-packages for skins (hercules, outlineClose, outline, traditional)
* Tue Jan  3 2006 oc2pus@arcor.de 1.4.2-0.oc2pus.1
- initial release of rpm
- repacked as tar.bz2
